@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.46.2.6 2004/06/16 05:28:59 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.46.2.7 2004/06/30 09:28:13 fuyu Exp $
  */
 
 #include "config.h"
@@ -1066,6 +1066,10 @@ bbs_thread_view_append_text(BBSThreadView *view, const gchar *text, int len)
   ApplyTagArgs args;
   int start_offset;
 
+#if ENABLE_STRICT_CHECK
+  ochusha_ensure_gdk_threads_entered();
+#endif
+
   g_return_if_fail(IS_BBS_THREAD_VIEW(view) && text != NULL);
 
   args.start = &start;
