@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: download_ui.c,v 1.11.2.3 2004/06/04 11:59:21 fuyu Exp $
+ * $Id: download_ui.c,v 1.11.2.4 2004/06/13 22:55:27 fuyu Exp $
  */
 
 #include "config.h"
@@ -95,7 +95,7 @@ access_progressed_cb(OchushaAsyncBuffer *buffer,
   if (!GTK_IS_WIDGET(download_dialog))
     return;
 
-  OCHU_THREADS_ENTER();
+  gdk_threads_enter();
 
   pbar = (GtkProgressBar *)g_object_get_qdata(G_OBJECT(download_dialog),
 					      progress_id);
@@ -114,7 +114,7 @@ access_progressed_cb(OchushaAsyncBuffer *buffer,
 	}
     }
 
-  OCHU_THREADS_LEAVE();
+  gdk_threads_leave();
 
   return;
 }
@@ -127,7 +127,7 @@ access_finished_cb(OchushaAsyncBuffer *buffer, GtkDialog *download_dialog)
   GtkProgressBar *pbar;
   g_return_if_fail(GTK_IS_DIALOG(download_dialog));
 
-  OCHU_THREADS_ENTER();
+  gdk_threads_enter();
 
   pbar = (GtkProgressBar *)g_object_get_qdata(G_OBJECT(download_dialog),
 					      progress_id);
@@ -137,7 +137,7 @@ access_finished_cb(OchushaAsyncBuffer *buffer, GtkDialog *download_dialog)
   gtk_dialog_set_response_sensitive(download_dialog,
 				    GTK_RESPONSE_OK, TRUE);
 
-  OCHU_THREADS_LEAVE();
+  gdk_threads_leave();
 
   return;
 }
@@ -153,7 +153,7 @@ access_failed_cb(OchushaAsyncBuffer *buffer,
   if (!GTK_IS_DIALOG(download_dialog))
     return;
 
-  OCHU_THREADS_ENTER();
+  gdk_threads_enter();
 
   pbar = (GtkProgressBar *)g_object_get_qdata(G_OBJECT(download_dialog),
 					      progress_id);
@@ -161,7 +161,7 @@ access_failed_cb(OchushaAsyncBuffer *buffer,
   gtk_dialog_set_response_sensitive(download_dialog,
 				    GTK_RESPONSE_OK, FALSE);
 
-  OCHU_THREADS_LEAVE();
+  gdk_threads_leave();
 
   return;
 }
@@ -175,8 +175,6 @@ download_dialog_response_cb(GtkWidget *widget, int response_id,
     = (OchushaAsyncBuffer *)g_object_get_qdata(G_OBJECT(widget), buffer_id);
   g_return_if_fail(GTK_IS_DIALOG(widget));
 
-  MAIN_THREAD_EVENT_CALLBACK();
-
   if (!OCHUSHA_IS_ASYNC_BUFFER(buffer))
     goto done;
 
@@ -204,14 +202,14 @@ download_dialog_response_cb(GtkWidget *widget, int response_id,
       fprintf(stderr, "Pre termination.\n");
       fprintf(stderr, "Pre gdk_threads_leave().\n");
 #endif
-      OCHU_THREADS_LEAVE();
+      gdk_threads_leave();
       ochusha_async_buffer_suspend(buffer);
       ochusha_async_buffer_terminate(buffer);
       /* ochusha_async_buffer_resume(buffer); */
 #if 0
       fprintf(stderr, "Post termination.\n");
 #endif
-      OCHU_THREADS_ENTER();
+      gdk_threads_enter();
 #if 0
       fprintf(stderr, "Post gdk_threads_enter().\n");
 #endif
@@ -222,7 +220,6 @@ download_dialog_response_cb(GtkWidget *widget, int response_id,
   gtk_widget_hide(widget);
   gtk_widget_unrealize(widget);
   gtk_widget_destroy(widget);
-  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -234,8 +231,6 @@ filesel_dialog_response_cb(GtkWidget *widget, int response_id,
   GtkWidget *download_dialog
     = (GtkWidget *)g_object_get_qdata(G_OBJECT(widget), dialog_id);
 
-  MAIN_THREAD_EVENT_CALLBACK();
-
   if (GTK_IS_DIALOG(download_dialog))
     {
       if (response_id == GTK_RESPONSE_OK)
@@ -254,11 +249,8 @@ filesel_dialog_response_cb(GtkWidget *widget, int response_id,
 	  gtk_widget_show(download_dialog);
 	}
     }
-  ENTER_MAIN_EVENT_LOOP();
-
   g_return_if_fail(GTK_IS_DIALOG(download_dialog));
 
-  MAIN_THREAD_EVENT_CALLBACK();
   if (response_id != GTK_RESPONSE_OK)
     {
       gtk_widget_hide(download_dialog);
@@ -269,7 +261,6 @@ filesel_dialog_response_cb(GtkWidget *widget, int response_id,
   gtk_widget_hide(widget);
   gtk_widget_unrealize(widget);
   gtk_widget_destroy(widget);
-  ENTER_MAIN_EVENT_LOOP();
 }
 
 
