@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: image_ui.c,v 1.5.2.12 2004/05/15 17:28:41 fuyu Exp $
+ * $Id: image_ui.c,v 1.5.2.14 2004/06/14 07:52:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -136,7 +136,7 @@ image_info_timeout_cb(ImageInfo *info)
   GSList *info_list;
   gboolean result = FALSE;
 
-  OCHU_THREADS_ENTER();
+  gdk_threads_enter();
 
   if (info->loader != NULL || info->widget_list != NULL)
     {
@@ -157,7 +157,7 @@ image_info_timeout_cb(ImageInfo *info)
   image_info_free(info);
 
  retry:
-  OCHU_THREADS_LEAVE();
+  gdk_threads_leave();
 
   return result;
 }
@@ -585,12 +585,12 @@ download_image(WorkerThread *employee, gpointer args)
 	    if (length > 0 && length > offset)
 	      {
 		size_t updated_len = length - offset;
-		OCHU_THREADS_ENTER();
+		gdk_threads_enter();
 		image_shown
 		  |= gdk_pixbuf_loader_write(loader,
 					     ((const guchar *)buffer->buffer
 					      + offset), updated_len, NULL);
-		OCHU_THREADS_LEAVE();
+		gdk_threads_leave();
 	      }
 	    if (buffer->fixed)
 	      goto terminated;
@@ -607,7 +607,8 @@ download_image(WorkerThread *employee, gpointer args)
       ochusha_async_buffer_active_unref(buffer);
     }
 
-  OCHU_THREADS_ENTER();
+  gdk_threads_enter();
+
   if (!image_shown)
     set_pixbuf(image_info);
 
@@ -616,7 +617,7 @@ download_image(WorkerThread *employee, gpointer args)
   image_info->loader = NULL;
   image_info->buffer = NULL;
 
-  OCHU_THREADS_LEAVE();
+  gdk_threads_leave();
 
   if (image_shown)
     {
@@ -891,11 +892,12 @@ cache_image(OchushaApplication *application, const char *url,
    *       capacity_of_image_cacheۤ뤳ȤΤϡˤʤ
    */
 
-  OCHU_THREADS_ENTER();
+  gdk_threads_enter();
   entry = g_hash_table_lookup(temporary_cache_table, url);
-  OCHU_THREADS_LEAVE();
+  gdk_threads_leave();
 
-  g_return_if_fail(entry == NULL);
+  if (entry != NULL)
+    return;
 
   filename = ochusha_utils_url_encode_string(url);
 
@@ -926,7 +928,7 @@ cache_image(OchushaApplication *application, const char *url,
 
   entry = cache_entry_new(filename, sb.st_atime, sb.st_size);
 
-  OCHU_THREADS_ENTER();
+  gdk_threads_enter();
   g_hash_table_insert(temporary_cache_table, G_STRDUP(url), entry);
   cache_entry_list = g_slist_insert_sorted(cache_entry_list, entry,
 					   cache_entry_compare);
@@ -935,7 +937,7 @@ cache_image(OchushaApplication *application, const char *url,
 
   ochusha_image_cache_ensure_limits(application);
 
-  OCHU_THREADS_LEAVE();
+  gdk_threads_leave();
 
 #ifdef DEBUG_CACHE
   fprintf(stderr, "\nCurrent Cache Status:\n");
