@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.28.2.8 2004/06/13 22:55:27 fuyu Exp $
+ * $Id: main.c,v 1.28.2.10 2004/06/26 18:03:30 fuyu Exp $
  */
 
 #include "config.h"
@@ -57,11 +57,14 @@
 
 
 #define INITIAL_NUM_THREADS		2
-#define MAXIMUM_NUM_THREADS		32
+#define MAXIMUM_NUM_THREADS		16
 #define MAXIMUM_NUM_MODEST_THREADS	4
+#define MAXIMUM_NUM_LOADER_THREADS	2
 
 
 #if GTK_MINOR_VERSION > 2
+#include <pthread.h>
+
 static Monitor *ochusha_gdk_threads_monitor = NULL;
 
 
@@ -77,6 +80,17 @@ ochusha_gdk_threads_leave(void)
 {
   ochusha_monitor_exit(ochusha_gdk_threads_monitor);
 }
+
+
+# if ENABLE_STRICT_CHECK
+void
+ochusha_ensure_gdk_threads_entered(void)
+{
+  g_assert(ochusha_gdk_threads_monitor->count > 0);
+  g_assert(pthread_equal(ochusha_gdk_threads_monitor->locker,
+			 pthread_self()));
+}
+# endif
 #endif
 
 
@@ -120,7 +134,9 @@ main(int argc, char *argv[])
   init_memory_trace();
 #endif
 
+#if GTK_MINOR_VERSION > 2
   ochusha_gdk_threads_monitor = ochusha_monitor_new(NULL);
+#endif
 
 #if TRACE_REFCOUNT
   init_refcount_trace();
@@ -247,7 +263,8 @@ main(int argc, char *argv[])
   initialize_common_converters();
 
   initialize_worker(INITIAL_NUM_THREADS, MAXIMUM_NUM_THREADS,
-		    MAXIMUM_NUM_MODEST_THREADS);
+		    MAXIMUM_NUM_MODEST_THREADS,
+		    MAXIMUM_NUM_LOADER_THREADS);
 
   resource_file = ochusha_config_find_file(&application->config,
 					   OCHUSHA_GTKRC, NULL);
@@ -402,8 +419,10 @@ main(int argc, char *argv[])
 
   G_FREE(application);
 
+#if GTK_MINOR_VERSION > 2
   ochusha_monitor_free(ochusha_gdk_threads_monitor);
   ochusha_gdk_threads_monitor = NULL;
+#endif
 
   dump_pointers();
 #endif
