@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui_private.h,v 1.11.2.4 2004/06/13 22:55:27 fuyu Exp $
+ * $Id: ochusha_ui_private.h,v 1.11.2.6 2004/06/30 09:29:19 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_PRIVATE_H_
@@ -43,17 +43,24 @@
 extern "C" {
 #endif
 
-#define DEBUG_GUI		0
-#define DEBUG_GUI_MOST		0
-#define DEBUG_THREAD		0
-#define DEBUG_THREAD_MOST	0
-#define DEBUG_WIDGET		0
-#define DEBUG_WIDGET_MOST	0
+#define DEBUG_GUI			0
+#define DEBUG_GUI_MOST			0
+#define DEBUG_THREAD			0
+#define DEBUG_THREAD_MOST		0
+#define DEBUG_WIDGET			0
+#define DEBUG_WIDGET_MOST		0
 
-#define DEBUG_TS_ENGINE		0
+#define DEBUG_TS_ENGINE			0
 
-#define ENABLE_STRICT_CHECK	0
-#define USE_THREAD_FOR_MAIN	0
+#define ENABLE_STRICT_CHECK		0
+#define USE_THREAD_FOR_MAIN		0
+
+#define GRAB_FOCUS_ON_ENTER_NOTIFY	0
+
+
+#if ENABLE_STRICT_CHECK
+void ochusha_ensure_gdk_threads_entered(void);
+#endif
 
 
 #ifdef __cplusplus
