@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: paned_notebook.h,v 1.8 2004/04/06 18:12:17 fuyu Exp $
+ * $Id: paned_notebook.h,v 1.8.2.2 2004/06/11 12:02:34 fuyu Exp $
  */
 
 #ifndef _PANED_NOTEBOOK_H_
@@ -52,7 +52,7 @@ typedef enum
   VPANED_STYLE
 } PanedStyleType;
 
-GType paned_style_get_type(void);
+GType paned_style_get_type(void) G_GNUC_CONST;
 #define PANED_STYLE_TYPE		(paned_style_get_type())
 
 
@@ -107,9 +107,6 @@ struct _PanedNotebook
 
   GtkActionGroup *action_group;
   GtkUIManager *ui_manager;
-# if 0	/* ̤ */
-  GtkAccelGroup *accel_group;
-# endif
 #endif
 
   /* contents_paneβ */
@@ -139,10 +136,12 @@ struct _PanedNotebookClass
 			   GtkWidget *item_view);
   void (*page_switched)(PanedNotebook *paned_notebook,
 			GtkWidget *previous_view, GtkWidget *current_view);
+  void (*page_double_clicked)(PanedNotebook *paned_notebook,
+			      gpointer item, GtkWidget *item_view);
 };
 
 
-GType paned_notebook_get_type(void);
+GType paned_notebook_get_type(void) G_GNUC_CONST;
 
 GtkWidget *paned_notebook_new(PanedStyleType paned_style);
 GtkWidget *paned_notebook_new_with_selector(PanedStyleType paned_style,
