@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: thread_proxy.h,v 1.3 2004/01/15 02:18:05 fuyu Exp $
+ * $Id: thread_proxy.h,v 1.3.2.1 2004/06/11 12:02:34 fuyu Exp $
  */
 
 #ifndef _THREAD_PROXY_H_
@@ -64,7 +64,7 @@ struct _ThreadProxyClass
 };
 
 
-GType thread_proxy_get_type(void);
+GType thread_proxy_get_type(void) G_GNUC_CONST;
 OchushaBBSThread *thread_proxy_new(const char *url, const gchar *title);
 OchushaBBSThread *thread_proxy_new_with_thread(OchushaBBSThread *thread);
 OchushaBBSThread *thread_proxy_get_real_thread(ThreadProxy *proxy);
