@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: monitor.c,v 1.1.2.6 2004/06/14 05:48:44 fuyu Exp $
+ * $Id: monitor.c,v 1.1.2.10 2004/06/15 10:36:12 fuyu Exp $
  */
 
 #include "config.h"
@@ -37,7 +37,7 @@
 #include <string.h>
 #include <time.h>
 
-#ifdef HAVE_CLOCK_GETTIME
+#if defined(HAVE_CLOCK_GETTIME) || defined(HAVE_GETTIMEOFDAY)
 # ifdef HAVE_SYS_TIME_H
 #  include <sys/time.h>
 # endif
@@ -104,21 +104,19 @@ ochusha_monitor_enter(Monitor *monitor)
       return;
     }
 
+#if CHECK_LOCK_ORDER
+  if (monitor->other != NULL && monitor->other->count > 0
+      && pthread_equal(monitor->other->locker, pthread_self()))
+    {
+      fprintf(stderr, "Lock Order Reversal: %p should follow %p\n",
+	      monitor->other, monitor);
+      abort();
+    }
+#endif
+
   if ((result = pthread_mutex_lock(&monitor->mutex)) == 0)
     {
-#if CHECK_LOCK_ORDER
-      pthread_t self = pthread_self();
-      if (monitor->other != NULL && monitor->other->count > 0
-	  && pthread_equal(monitor->other->locker, self))
-	{
-	  fprintf(stderr, "Lock Order Reversal: %p should follow %p\n",
-		  monitor->other, monitor);
-	  abort();
-	}
-      monitor->locker = self;
-#else
       monitor->locker = pthread_self();
-#endif
       monitor->count = 1;
       return;
     }
@@ -141,44 +139,29 @@ ochusha_monitor_try_enter(Monitor *monitor)
       return 1;
     }
 
+#if CHECK_LOCK_ORDER
+  if (monitor->other != NULL && monitor->other->count > 0
+      && pthread_equal(monitor->other->locker, pthread_self()))
+    {
+      fprintf(stderr, "Lock Order Reversal: %p should follow %p\n",
+	      monitor->other, monitor);
+      abort();
+    }
+#endif
+
   if ((result = pthread_mutex_trylock(&monitor->mutex)) == 0)
     {
-#if CHECK_LOCK_ORDER
-      pthread_t self = pthread_self();
-      if (monitor->other != NULL && monitor->other->count > 0
-	  && pthread_equal(monitor->other->locker, self))
-	{
-	  fprintf(stderr, "Lock Order Reversal: %p should follow %p\n",
-		  monitor->other, monitor);
-	  abort();
-	}
-      monitor->locker = self;
-#else
       monitor->locker = pthread_self();
-#endif
       monitor->count = 1;
       return 1;
     }
 
   if (result == EBUSY)
-    {
-#if CHECK_LOCK_ORDER
-      if (monitor->other != NULL)
-	{
-	  pthread_t self = pthread_self();
-	  if (monitor->other->count > 0
-	      && pthread_equal(monitor->other->locker, self))
-	    {
-	      fprintf(stderr, "Lock Order Reversal: %p should follow %p\n",
-		      monitor->other, monitor);
-	      abort();
-	    }
-	}
-#endif
-      return 0;
-    }
+    return 0;
 
-  fprintf(stderr, "Couldn't lock a mutex: %s(%d)\n", strerror(result), result);
+  /* EBUSYʳϲ */
+  fprintf(stderr, "Couldn't trylock a mutex: %s(%d)\n",
+	  strerror(result), result);
   abort();
 }
 
@@ -187,9 +170,12 @@ void
 ochusha_monitor_exit(Monitor *monitor)
 {
   int result;
-  if (monitor->count > 1 && !pthread_equal(monitor->locker, pthread_self()))
+  if (monitor->count < 1 || !pthread_equal(monitor->locker, pthread_self()))
     {
       fprintf(stderr, "Couldn't unlock a mutex held by another thread!\n");
+      fprintf(stderr,
+	      "Couldn't unlock a mutex: locker=%p, self=%p, count=%d\n",
+	      monitor->locker, pthread_self(), monitor->count);
       abort();
     }
 
@@ -218,9 +204,8 @@ ochusha_monitor_wait(Monitor *monitor)
 #if CHECK_LOCK_ORDER
   if (monitor->other != NULL)
     {
-      pthread_t self = pthread_self();
       if (monitor->other->count > 0
-	  && pthread_equal(monitor->other->locker, self))
+	  && pthread_equal(monitor->other->locker, pthread_self()))
 	{
 	  fprintf(stderr, "Lock Order Reversal: attemplt to wait on %p during %p held.\n", monitor, monitor->other);
 	  abort();
@@ -235,8 +220,14 @@ ochusha_monitor_wait(Monitor *monitor)
       abort();
     }
 
-  monitor->count = prev_count;
+  if (monitor->count != 0)
+    {
+      fprintf(stderr, "Monitor protocol error.\n");
+      abort();
+    }
+
   monitor->locker = pthread_self();
+  monitor->count = prev_count;
   ochusha_monitor_exit(monitor);
 }
 
@@ -244,13 +235,14 @@ ochusha_monitor_wait(Monitor *monitor)
 int
 ochusha_monitor_timedwait(Monitor *monitor, long ms)
 {
-#ifdef HAVE_CLOCK_GETTIME
+#if defined(HAVE_CLOCK_GETTIME) || defined(HAVE_GETTIMEOFDAY)
   struct timespec abstime;
   int prev_count;
   int result;
 
   if (ms > 0)
     {
+# ifdef HAVE_CLOCKGETTIME
       if (clock_gettime(CLOCK_REALTIME, &abstime) == 0)
 	{
 	  long nsec = abstime.tv_nsec + (ms % 1000) * 1000000;
@@ -259,70 +251,66 @@ ochusha_monitor_timedwait(Monitor *monitor, long ms)
 	}
       else
 	ms = 0;
+# else
+      struct timeval abstime_now;
+      if (gettimeofday(&abstime_now, NULL) == 0)
+	{
+	  long nsec;
+	  abstime.tv_sec = abstime_now.tv_sec;
+	  abstime.tv_nsec = abstime_now.tv_usec * 1000;
+
+	  nsec = abstime.tv_nsec + (ms % 1000) * 1000000;
+	  abstime.tv_sec += (ms / 1000) + (nsec / 1000000000);
+	  abstime.tv_nsec = nsec % 1000000000;
+	}
+      else
+	ms = 0;
+# endif
+    }
+
+  if (ms == 0)
+    {
+      ochusha_monitor_wait(monitor);
+      return 1;
     }
 
   ochusha_monitor_enter(monitor);
   prev_count = monitor->count;
   monitor->count = 0;
 
-#if CHECK_LOCK_ORDER
+# if CHECK_LOCK_ORDER
   if (monitor->other != NULL)
     {
-      pthread_t self = pthread_self();
       if (monitor->other->count > 0
-	  && pthread_equal(monitor->other->locker, self))
+	  && pthread_equal(monitor->other->locker, pthread_self()))
 	{
 	  fprintf(stderr, "Lock Order Reversal: attemplt to wait on %p during %p held.\n", monitor, monitor->other);
 	  abort();
 	}
     }
-#endif
+# endif
 
-  if (ms == 0)
-    {
-      if ((result = pthread_cond_wait(&monitor->cond, &monitor->mutex)) != 0)
-	{
-	  fprintf(stderr, "Couldn't wait a condition: %s(%d)\n",
-		  strerror(result), result);
-	  abort();
-	}
-    }
-  else
-    {
-      result = pthread_cond_timedwait(&monitor->cond, &monitor->mutex,
-				      &abstime);
-      if (result != 0 && result != ETIMEDOUT)
-	{
-	  fprintf(stderr, "Couldn't wait a condition: %s(%d)\n",
-		  strerror(result), result);
-	  abort();
-	}
-    }
-  result = (result == 0);
-
-  monitor->count = prev_count;
-  monitor->locker = pthread_self();
-  ochusha_monitor_exit(monitor);
-
-  return result;
-#else
-  int prev_count;
-  int result;
-  ochusha_monitor_enter(monitor);
-  prev_count = monitor->count;
-  monitor->count = 0;
-
-  if ((result = pthread_cond_wait(&monitor->cond, &monitor->mutex)) != 0)
+  result = pthread_cond_timedwait(&monitor->cond, &monitor->mutex, &abstime);
+  if (result != 0 && result != ETIMEDOUT)
     {
       fprintf(stderr, "Couldn't wait a condition: %s(%d)\n",
 	      strerror(result), result);
       abort();
     }
 
-  monitor->count = prev_count;
+  if (monitor->count != 0)
+    {
+      fprintf(stderr, "Monitor protocol error.\n");
+      abort();
+    }
+
   monitor->locker = pthread_self();
+  monitor->count = prev_count;
   ochusha_monitor_exit(monitor);
 
+  return result == 0;
+#else
+  ochusha_monitor_wait(monitor);
   return 1;
 #endif
 }
