@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_async_buffer.c,v 1.34.2.3 2004/06/06 15:39:14 fuyu Exp $
+ * $Id: ochusha_async_buffer.c,v 1.34.2.4 2004/06/13 02:23:13 fuyu Exp $
  */
 
 #include "config.h"
@@ -681,14 +681,13 @@ ochusha_async_buffer_suspend(OchushaAsyncBuffer *buffer)
   LOCK_BUFFER_LOCK(buffer);
   buffer->number_of_suspended_users = 0;
   buffer->state = OCHUSHA_ASYNC_BUFFER_SUSPENDED;
-  BROADCAST_BUFFER_CONDITION(buffer);
-
-  ochusha_monitor_enter(global_monitor);
 
   g_signal_emit(G_OBJECT(buffer),
 		async_buffer_signals[WAKEUP_NOW_SIGNAL],
 		0);
 
+  BROADCAST_BUFFER_CONDITION(buffer);
+
   while (buffer->number_of_suspended_users < buffer->number_of_active_users)
     {
       UNLOCK_BUFFER_LOCK(buffer);
@@ -697,13 +696,11 @@ ochusha_async_buffer_suspend(OchushaAsyncBuffer *buffer)
 #if 0
 	  fprintf(stderr, "Some threads not responding...\n");
 #endif
-	  goto finish;
+	  return;
 	}
       LOCK_BUFFER_LOCK(buffer);
     }
   UNLOCK_BUFFER_LOCK(buffer);
- finish:
-  ochusha_monitor_exit(global_monitor);
 }
 
 
@@ -738,14 +735,13 @@ ochusha_async_buffer_terminate(OchushaAsyncBuffer *buffer)
 
   LOCK_BUFFER_LOCK(buffer);
   buffer->state = OCHUSHA_ASYNC_BUFFER_TERMINATED;
-  BROADCAST_BUFFER_CONDITION(buffer);
-
-  ochusha_monitor_enter(global_monitor);
 
   g_signal_emit(G_OBJECT(buffer),
 		async_buffer_signals[WAKEUP_NOW_SIGNAL],
 		0);
 
+  BROADCAST_BUFFER_CONDITION(buffer);
+
   while (buffer->number_of_active_users > 0)
     {
       UNLOCK_BUFFER_LOCK(buffer);
@@ -754,14 +750,11 @@ ochusha_async_buffer_terminate(OchushaAsyncBuffer *buffer)
 #if 0
 	  fprintf(stderr, "Some threads not responding...\n");
 #endif
-	  goto finish;
+	  return;
 	}
       LOCK_BUFFER_LOCK(buffer);
     }
   UNLOCK_BUFFER_LOCK(buffer);
-
- finish:
-  ochusha_monitor_exit(global_monitor);
 }
 
 
