@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.45.2.2 2004/06/04 18:57:55 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.45.2.3 2004/06/16 05:24:36 fuyu Exp $
  */
 
 #include "config.h"
@@ -1088,10 +1088,6 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 
   g_return_val_if_fail(OCHUSHA_IS_BOARD_2CH(board) && status != NULL, FALSE);
 
-  converter = iconv_open("UTF-8//IGNORE",
-			 ochusha_board_2ch_get_subject_txt_encoding(board));
-  g_return_val_if_fail(converter != (iconv_t)-1, FALSE);
-
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
@@ -1104,6 +1100,14 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
       converter_helper = NULL;
     }
 
+  if (converter_helper != NULL)
+    converter = iconv_open("UTF-8",
+			   ochusha_board_2ch_get_subject_txt_encoding(board));
+  else
+    converter = iconv_open("UTF-8//IGNORE",
+			   ochusha_board_2ch_get_subject_txt_encoding(board));
+  g_return_val_if_fail(converter != (iconv_t)-1, FALSE);
+
   if (!ochusha_async_buffer_active_ref(buffer))
     {
 #if DEBUG_ASYNC_BUFFER_MOST
@@ -1208,9 +1212,18 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 							       thread_title);
 		G_FREE(thread_title);
 	      }
-#if DEBUG_LIBOCHUSHA
+#if 1	/* 쥿äƤޤäĶ */
 	    else
-	      fprintf(stderr, "thread found: %s\n", thread_id);
+	      {
+		thread_title = simple_string_canon(title_pos, title_len,
+						   converter,
+						   converter_helper);
+		ochusha_bbs_thread_set_title(thread, thread_title);
+		G_FREE(thread_title);
+#if DEBUG_LIBOCHUSHA
+		fprintf(stderr, "thread found: %s\n", thread_id);
+#endif
+	      }
 #endif
 
 	    if (thread_id != default_buffer)
