@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.17.2.1 2004/05/24 10:00:55 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.17.2.2 2004/06/16 05:25:10 fuyu Exp $
  */
 
 #include "config.h"
@@ -736,10 +736,6 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 
   g_return_val_if_fail(OCHUSHA_IS_BOARD_2CH(board) && status != NULL, FALSE);
 
-  converter = iconv_open("UTF-8//IGNORE",
-			 ochusha_board_jbbs_get_subject_txt_encoding(board));
-  g_return_val_if_fail(converter != (iconv_t)-1, FALSE);
-
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_MACHIBBS:
@@ -751,6 +747,14 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
       converter_helper = NULL;
     }
 
+  if (converter_helper != NULL)
+    converter = iconv_open("UTF-8",
+			   ochusha_board_jbbs_get_subject_txt_encoding(board));
+  else
+    converter = iconv_open("UTF-8//IGNORE",
+			   ochusha_board_jbbs_get_subject_txt_encoding(board));
+  g_return_val_if_fail(converter != (iconv_t)-1, FALSE);
+
   if (!ochusha_async_buffer_active_ref(buffer))
     {
 #if DEBUG_ASYNC_BUFFER_MOST
@@ -848,6 +852,16 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 							       thread_title);
 		G_FREE(thread_title);
 	      }
+#if 1	/* 쥿äƤޤäĶ */
+	    else
+	      {
+		thread_title = simple_string_canon(title_pos, title_len,
+						   converter,
+						   converter_helper);
+		ochusha_bbs_thread_set_title(thread, thread_title);
+		G_FREE(thread_title);
+	      }
+#endif
 
 	    if (thread_id != default_buffer)
 	      G_FREE(thread_id);
