@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.h,v 1.25 2004/02/26 06:05:10 fuyu Exp $
+ * $Id: ochusha_bulletin_board.h,v 1.27.2.3 2004/06/11 12:00:48 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BULLETIN_BOARD_H_
@@ -32,12 +32,11 @@
 #include "ochusha.h"
 #include "ochusha_async_buffer.h"
 #include "ochusha_network_broker.h"
+#include "monitor.h"
 
 #include <glib-object.h>
 #include <glib.h>
 
-#include <pthread.h>
-
 #include <zlib.h>
 
 
@@ -99,9 +98,7 @@ struct _OchushaBulletinBoard
   gboolean hidden;		/* İ鱣 */
   gboolean killed;		/* İ¸˼ΤƤ */
 
-  volatile gboolean is_busy;
-  pthread_mutex_t thread_list_lock;
-  pthread_cond_t thread_list_cond;
+  Monitor *monitor;
 };
 
 
@@ -113,19 +110,20 @@ struct _OchushaBulletinBoardClass
   void (*read_boardlist_element)(OchushaBulletinBoard *board,
 				 GHashTable *board_attributes);
   void (*write_boardlist_element)(OchushaBulletinBoard *board,
-				  gzFile *boardlist_xml);
+				  gzFile boardlist_xml);
   void (*threadlist_read_thread_element)(OchushaBulletinBoard *board,
 					 OchushaBBSThread *thread,
 					 GHashTable *thread_attributes);
   void (*threadlist_write_thread_element)(OchushaBulletinBoard *board,
 					  OchushaBBSThread *thread,
-					  gzFile *threadlist_xml);
+					  gzFile threadlist_xml);
 
   /* virtual function table */
   void (*recover_threadlist)(OchushaBulletinBoard *board,
 			     OchushaConfig *config);
   char *(*generate_base_path)(OchushaBulletinBoard *board, const char *url);
   char *(*generate_board_id)(OchushaBulletinBoard *board, const char *url);
+  void (*server_changed)(OchushaBulletinBoard *board, const char *prev_server);
   OchushaBBSThread *(*thread_new)(OchushaBulletinBoard *board,
 				  const char *id, const gchar *title);
   OchushaBBSThread *(*lookup_thread_by_url)(OchushaBulletinBoard *board,
@@ -166,7 +164,7 @@ struct _OchushaBulletinBoardClass
 };
 
 
-GType ochusha_bulletin_board_get_type(void);
+GType ochusha_bulletin_board_get_type(void) G_GNUC_CONST;
 OchushaBulletinBoard *ochusha_bulletin_board_new(const gchar *name,
 						 const char *url);
 
@@ -182,6 +180,10 @@ const char *ochusha_bulletin_board_get_server(OchushaBulletinBoard *board);
 const char *ochusha_bulletin_board_get_base_path(OchushaBulletinBoard *board);
 const char *ochusha_bulletin_board_get_id(OchushaBulletinBoard *board);
 
+void ochusha_bulletin_board_process_board_move(OchushaBulletinBoard *board,
+					       const char *new_url,
+					       OchushaConfig *config);
+
 void ochusha_bulletin_board_set_bbs_type(OchushaBulletinBoard *board,
 					 int bbs_type);
 int ochusha_bulletin_board_get_bbs_type(OchushaBulletinBoard *board);
