@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.28.2.2 2004/05/15 16:32:11 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.28.2.3 2004/05/24 10:04:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -1174,6 +1174,13 @@ ochusha_read_config_xml(OchushaConfig *config, const char *subdir,
 	= ochusha_utils_get_attribute_string(pref, "login_2ch_url");
       if (config->login_2ch_url == NULL)
 	config->login_2ch_url = G_STRDUP(OCHUSHA_DOLIB_URL);
+      else if (strcmp(config->login_2ch_url,
+		      "https://tiger2.he.net/~tora3n2c/futen.cgi") == 0)
+	{
+	  /* URLѹ */
+	  G_FREE(config->login_2ch_url);
+	  config->login_2ch_url = G_STRDUP(OCHUSHA_DOLIB_URL);
+	}
 
       config->offline = ochusha_utils_get_attribute_boolean(pref, "offline");
 
