@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.60.2.6 2004/06/13 02:24:07 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.60.2.9 2004/06/26 18:02:59 fuyu Exp $
  */
 
 #include "config.h"
@@ -43,6 +43,10 @@
 #include <errno.h>
 #include <fcntl.h>
 
+#ifdef HAVE_SCHED_H
+#include <sched.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -753,8 +757,11 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
       sync_object->finished = TRUE;
       UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
-      ghttp_request_destroy(request);
-      args->request = NULL;
+      if (args->request != NULL)
+	{
+	  args->request = NULL;
+	  ghttp_request_destroy(request);
+	}
 
       return FALSE;
     }    
@@ -809,8 +816,11 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 	      sync_object->finished = TRUE;
 	      UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
-	      ghttp_request_destroy(request);
-	      args->request = NULL;
+	      if (args->request != NULL)
+		{
+		  args->request = NULL;
+		  ghttp_request_destroy(request);
+		}
 
 	      snprintf(message, LOG_MESSAGE_SIZE,
 		       _("Access Timeout: %s\n"), url);
@@ -866,8 +876,11 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 		  sync_object->finished = TRUE;
 		  UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
-		  ghttp_request_destroy(request);
-		  args->request = NULL;
+		  if (args->request != NULL)
+		    {
+		      args->request = NULL;
+		      ghttp_request_destroy(request);
+		    }
 
 		  snprintf(message, LOG_MESSAGE_SIZE,
 			   _("Cache is fresh: %s\n"), url);
@@ -913,8 +926,11 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 
 	  if (!ochusha_async_buffer_append_data(buffer, body, body_len))
 	    {
-	      ghttp_request_destroy(request);
-	      args->request = NULL;
+	      if (args->request != NULL)
+		{
+		  args->request = NULL;
+		  ghttp_request_destroy(request);
+		}
 
 	      status->state
 		= OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
@@ -935,8 +951,11 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 	{
 	  if (!ochusha_async_buffer_signal(buffer))
 	    {
-	      ghttp_request_destroy(request);
-	      args->request = NULL;
+	      if (args->request != NULL)
+		{
+		  args->request = NULL;
+		  ghttp_request_destroy(request);
+		}
 
 	      status->state
 		= OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
@@ -990,8 +1009,11 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 
       ochusha_async_buffer_emit_access_finished(buffer);
 
-      ghttp_request_destroy(request);
-      args->request = NULL;
+      if (args->request != NULL)
+	{
+	  args->request = NULL;
+	  ghttp_request_destroy(request);
+	}
 
       snprintf(message, LOG_MESSAGE_SIZE,
 	       _("Access completed: %s\n"),
@@ -1082,8 +1104,11 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 #endif
     }
 
-  ghttp_request_destroy(request);
-  args->request = NULL;
+  if (args->request != NULL)
+    {
+      args->request = NULL;
+      ghttp_request_destroy(request);
+    }
 
   return FALSE;
 
@@ -1106,7 +1131,10 @@ destruct_job_args(NetworkBrokerJobArgs *job_args)
     G_FREE(job_args->if_modified_since);
 
   if (job_args->request != NULL)
-    ghttp_request_destroy(job_args->request);
+    {
+      ghttp_request_destroy(job_args->request);
+      job_args->request = NULL;
+    }
 
   G_FREE(job_args);
 }
@@ -1196,6 +1224,24 @@ ochusha_network_broker_employ_worker_thread(OchushaNetworkBroker *broker,
 	  || ochusha_config_cache_file_exist(broker->config, url)))
     args->if_modified_since = G_STRDUP(if_modified_since);
 
+  while (g_object_get_qdata(G_OBJECT(buffer), broker_job_args_id) != NULL)
+    {
+#ifdef HAVE_SCHED_YIELD
+      sched_yield();
+#else
+# ifdef HAVE_NANOSLEEP
+      struct timespec rqtp { 0, 100000000 };
+      nanosleep(&rqtp, NULL);
+# else
+#  ifdef HAVE_USLEEP
+      usleep(1000);
+#  else
+      sleep(1);
+#  endif
+# endif
+#endif
+    }
+
   g_object_set_qdata_full(G_OBJECT(buffer), broker_job_args_id,
 			  args, (GDestroyNotify)destruct_job_args);
 
@@ -1268,6 +1314,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
 
       ochusha_async_buffer_fix(buffer);
+      ochusha_async_buffer_active_unref(buffer);
       g_object_set_qdata(G_OBJECT(buffer), broker_job_args_id, NULL);
       OCHU_OBJECT_UNREF(buffer);
 
@@ -1289,6 +1336,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	{
 	  status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
 	  ochusha_async_buffer_fix(buffer);
+	  ochusha_async_buffer_active_unref(buffer);
 	  g_object_set_qdata(G_OBJECT(buffer), broker_job_args_id, NULL);
 	  OCHU_OBJECT_UNREF(buffer);
 
@@ -1367,8 +1415,11 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 			OCHUSHA_NETWORK_BROKER_FAILURE_REASON_INVALID_PROXY,
 			_("Proxy setting may be wrong."));
 
-	  ghttp_request_destroy(request);
-	  args->request = NULL;
+	  if (args->request != NULL)
+	    {
+	      args->request = NULL;
+	      ghttp_request_destroy(request);
+	    }
 
 	  goto finish_try_update_cache;
 	}
@@ -1388,8 +1439,11 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       if (!ochusha_async_buffer_update_length(buffer, offset))
 	{
 	  status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_OK;
-	  ghttp_request_destroy(request);
-	  args->request = NULL;
+	  if (args->request != NULL)
+	    {
+	      args->request = NULL;
+	      ghttp_request_destroy(request);
+	    }
 
 	  snprintf(message, LOG_MESSAGE_SIZE,
 		   _("Access terminated: %s\n"), url);
@@ -1465,8 +1519,11 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
 		  ochusha_async_buffer_emit_access_finished(buffer);
 
-		  ghttp_request_destroy(request);
-		  args->request = NULL;
+		  if (args->request != NULL)
+		    {
+		      args->request = NULL;
+		      ghttp_request_destroy(request);
+		    }
 
 		  snprintf(message, LOG_MESSAGE_SIZE,
 			   _("Cache is fresh: %s\n"), url);
@@ -1513,8 +1570,11 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		{
 		  status->state
 		    = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_OK;
-		  ghttp_request_destroy(request);
-		  args->request = NULL;
+		  if (args->request != NULL)
+		    {
+		      args->request = NULL;
+		      ghttp_request_destroy(request);
+		    }
 		  
 		  snprintf(message, LOG_MESSAGE_SIZE,
 			   _("Access terminated: %s\n"), url);
@@ -1551,8 +1611,11 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		{
 		  status->state
 		    = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_OK;
-		  ghttp_request_destroy(request);
-		  args->request = NULL;
+		  if (args->request != NULL)
+		    {
+		      args->request = NULL;
+		      ghttp_request_destroy(request);
+		    }
 
 		  snprintf(message, LOG_MESSAGE_SIZE,
 			   _("Access terminated: %s\n"),
@@ -1604,8 +1667,11 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       status->status_code = status_code;
       ochusha_async_buffer_emit_access_finished(buffer);
 
-      ghttp_request_destroy(request);
-      args->request = NULL;
+      if (args->request != NULL)
+	{
+	  args->request = NULL;
+	  ghttp_request_destroy(request);
+	}
       write_buffer_to_cache(broker, args->cache_url, buffer);
 
       snprintf(message, LOG_MESSAGE_SIZE, _("Cache updated: %s\n"), url);
@@ -1617,8 +1683,8 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY;
       if (request != NULL)
 	{
-	  ghttp_request_destroy(request);
 	  args->request = NULL;
+	  ghttp_request_destroy(request);
 	}
 
       snprintf(message, LOG_MESSAGE_SIZE,
@@ -1712,9 +1778,11 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 #endif
     }
 
-  if (request != NULL)
-    ghttp_request_destroy(request);
-  args->request = NULL;
+  if (args->request != NULL)
+    {
+      args->request = NULL;
+      ghttp_request_destroy(request);
+    }
 
  finish_try_update_cache:
   LOCK_WORKER_SYNC_OBJECT(sync_object);
@@ -1748,6 +1816,7 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       ochusha_async_buffer_emit_access_failed(buffer,
 		OCHUSHA_NETWORK_BROKER_FAILURE_REASON_ACCESS_TERMINATED,
 		_("Access terminated."));
+      ochusha_async_buffer_fix(buffer);
       goto finish_refresh_cache_after_read;
     }
 
@@ -1758,6 +1827,8 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       ochusha_async_buffer_emit_access_failed(buffer,
 		OCHUSHA_NETWORK_BROKER_FAILURE_REASON_ACCESS_TERMINATED,
 		_("Access terminated."));
+      ochusha_async_buffer_fix(buffer);
+      ochusha_async_buffer_active_unref(buffer);
       goto finish_refresh_cache_after_read;
     }
 
@@ -1823,10 +1894,10 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	}
     }
 
+  ochusha_async_buffer_fix(buffer);
   ochusha_async_buffer_active_unref(buffer);
 
  finish_refresh_cache_after_read:
-  ochusha_async_buffer_fix(buffer);
   g_object_set_qdata(G_OBJECT(buffer), broker_job_args_id, NULL);
   OCHU_OBJECT_UNREF(buffer);
 }
@@ -1848,6 +1919,7 @@ force_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   if (!ochusha_async_buffer_active_ref(buffer))
     {
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
+      ochusha_async_buffer_fix(buffer);
       goto finish_force_read;
     }
 
@@ -1855,6 +1927,8 @@ force_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   if (args == NULL)
     {
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
+      ochusha_async_buffer_fix(buffer);
+      ochusha_async_buffer_active_unref(buffer);
       goto finish_force_read;
     }
 
@@ -1883,10 +1957,10 @@ force_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 #endif
     }
 
+  ochusha_async_buffer_fix(buffer);
   ochusha_async_buffer_active_unref(buffer);
 
  finish_force_read:
-  ochusha_async_buffer_fix(buffer);
   g_object_set_qdata(G_OBJECT(buffer), broker_job_args_id, NULL);
   OCHU_OBJECT_UNREF(buffer);
 }
@@ -1904,6 +1978,7 @@ background_read_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   if (!ochusha_async_buffer_active_ref(buffer))
     {
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
+      ochusha_async_buffer_fix(buffer);
       goto finish_job;
     }
 
@@ -1918,10 +1993,10 @@ background_read_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
     }
 
+  ochusha_async_buffer_fix(buffer);
   ochusha_async_buffer_active_unref(buffer);
 
  finish_job:
-  ochusha_async_buffer_fix(buffer);
   OCHU_OBJECT_UNREF(buffer);
   OCHU_OBJECT_UNREF(broker);
 }
@@ -2074,7 +2149,7 @@ ochusha_network_broker_read_from_url_full(OchushaNetworkBroker *broker,
 	  OCHU_OBJECT_REF(broker);
 	  OCHU_OBJECT_REF(buffer);
 
-	  commit_job(job);
+	  commit_loader_job(job);
 
 	  return buffer;
 	}
