@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.71.2.1 2004/05/30 14:50:10 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.71.2.2 2004/06/26 18:53:37 fuyu Exp $
  */
 
 #include "config.h"
@@ -398,7 +398,8 @@ ochusha_thread_2ch_check_url(OchushaBBSThread *thread, const char *url,
 	  board_id, thread_id);
 #endif
   if (strcmp(ochusha_bulletin_board_get_id(thread->board), board_id) == 0
-      && thread_id != NULL && strcmp(thread->id, thread_id) == 0)
+      && thread_id != NULL
+      && (*thread_id == '\0' || strcmp(thread->id, thread_id) == 0))
     result = TRUE;
   else
     result = FALSE;
