@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.40.2.5 2004/06/08 15:32:14 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.40.2.7 2004/06/29 23:19:47 fuyu Exp $
  */
 
 #include "config.h"
@@ -82,7 +82,7 @@ parse_thread_path(char *path, char **thread_id_p,
   char *thread_id = NULL;
   unsigned int from = 0;
   unsigned int to = 0;
-  char *slash_pos = strchr(path + 1, '/');
+  char *slash_pos = strchr(path, '/');
 
 #if 0
   fprintf(stderr, "parse_thread_path()\n");
@@ -96,40 +96,31 @@ parse_thread_path(char *path, char **thread_id_p,
       else
 	thread_id = path;
 
-      if (is_thread_id(thread_id))
-	{
-	  path = slash_pos + 1;
+      path = slash_pos + 1;
 
-	  if (*path != '\0')
+      if (*path != '\0')
+	{
+	  char tmp_char;
+	  char *hyphen_pos = strchr(path, '-');
+	  if (hyphen_pos != NULL)
 	    {
-	      char tmp_char;
-	      char *hyphen_pos = strchr(path, '-');
-	      if (hyphen_pos != NULL)
-		{
-		  tmp_char = *hyphen_pos;
-		  *hyphen_pos = '\0';
-		}
-	      else
-		tmp_char = '\0';
+	      tmp_char = *hyphen_pos;
+	      *hyphen_pos = '\0';
+	    }
+	  else
+	    tmp_char = '\0';
 
-	      if (hyphen_pos != path)
-		{
-		  if (sscanf(path, "%d", &from) != 1)
-		    from = 0;
-		}
+	  if (hyphen_pos != path)
+	    {
+	      if (sscanf(path, "%d", &from) != 1)
+		from = 0;
+	    }
 
-	      if (hyphen_pos != NULL && hyphen_pos[1] != '\0')
-		{
-		  if (sscanf(hyphen_pos + 1, "%d", &to) != 1)
-		    to = from;
-		}
+	  if (hyphen_pos != NULL && hyphen_pos[1] != '\0')
+	    {
+	      if (sscanf(hyphen_pos + 1, "%d", &to) != 1)
+		to = from;
 	    }
-	}
-      else
-	{
-	  if (thread_id != path)
-	    G_FREE(thread_id);
-	  thread_id = NULL;
 	}
     }
   else
@@ -379,6 +370,12 @@ ochusha_utils_2ch_check_url(const char *url, char **board_url_p,
 		  slash_pos[0] = tmp_char;
 
 		  parse_thread_path(slash_pos + 1, &thread_id, &from, &to);
+		  if (thread_id != NULL && *thread_id == '\0'
+		      && board_url_p != NULL)
+		    {
+		      G_FREE(thread_id);
+		      thread_id = NULL;
+		    }
 		}
 	      else
 		board_url[0] = '\0';
@@ -455,6 +452,11 @@ ochusha_utils_2ch_check_url(const char *url, char **board_url_p,
 			  board_id = G_STRDUP(board_id_head);
 			  *slash_pos = '/';
 			  parse_thread_path(slash_pos + 1, &thread_id, &from, &to);
+			  if (thread_id != NULL && !is_thread_id(thread_id))
+			    {
+			      G_FREE(thread_id);
+			      thread_id = NULL;
+			    }
 			}
 		      else
 			board_url[0] = '\0';
@@ -550,6 +552,11 @@ ochusha_utils_2ch_check_url(const char *url, char **board_url_p,
 		  fprintf(stderr, "board_url=\"%s\"\n", board_url);
 #endif
 		  parse_thread_path(slash_pos + 1, &thread_id, &from, &to);
+		  if (thread_id != NULL && !is_thread_id(thread_id))
+		    {
+		      G_FREE(thread_id);
+		      thread_id = NULL;
+		    }
 		}
 	      else
 		{
@@ -749,6 +756,13 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 #endif
       board = ochusha_bbs_table_lookup_board_by_url(table, url);
       board_by_name = ochusha_bbs_table_lookup_board_by_name(table, name);
+
+      if (board != NULL
+	  && strcmp(ochusha_bulletin_board_get_base_url(board), url) != 0)
+	{
+	  board_by_name = board;
+	  board = NULL;
+	}
       if (board_by_name != NULL
 	  && (board_by_name->bbs_type != OCHUSHA_BBS_TYPE_2CH
 	      && board_by_name->bbs_type != OCHUSHA_BBS_TYPE_MACHIBBS))
